@@ -241,6 +241,20 @@ if((GLOBALS->which_t_color > 0) && (GLOBALS->which_t_color <= WAVE_NUM_RAINBOW))
 if(GLOBALS->default_flags&TR_NUMMASK) t->flags=GLOBALS->default_flags;
 	else t->flags=(t->flags&TR_NUMMASK)|GLOBALS->default_flags;
 
+if(!t->vector && GLOBALS->enum_nptrs_jrb)
+	{
+	JRB enum_nptr = jrb_find_vptr(GLOBALS->enum_nptrs_jrb, t->n.nd);
+	if(enum_nptr)
+		{
+		int e_filter = enum_nptr->val.ui;
+		if((e_filter > 0) && (e_filter <= GLOBALS->num_xl_enum_filter))
+			{
+			t->e_filter = e_filter;
+			if(!(GLOBALS->default_flags&TR_NUMMASK)) t->flags = (t->flags & (~TR_NUMMASK)) | TR_ENUM | TR_BIN; /* need to downgrade to bin to make visible */
+			}
+		}
+	}
+
 if(GLOBALS->default_flags & TR_FTRANSLATED)
 	{
 	t->f_filter = GLOBALS->current_translate_file;
@@ -260,7 +274,7 @@ if(GLOBALS->default_flags & TR_TTRANSLATED)
 		if(!t->vector)
 			{
 			bvptr v;
-			int cache_hi = t->flags & TR_HIGHLIGHT;
+			TraceFlagsType cache_hi = t->flags & TR_HIGHLIGHT;
 
 			t->flags |= TR_HIGHLIGHT;
                         v = combine_traces(1, t); /* down: make single signal a vector */
@@ -365,7 +379,7 @@ int AddBlankTrace(char *commentname)
 {
   Trptr  t;
   char *comment;
-  unsigned int flags_filtered;
+  TraceFlagsType flags_filtered;
 
   if( (t = (Trptr) calloc_2( 1, sizeof( TraceEnt ))) == NULL )
     {
@@ -398,7 +412,7 @@ int AddBlankTrace(char *commentname)
 /*
  * Insert a blank [or comment] trace into the display...
  */
-int InsertBlankTrace(char *comment, int different_flags)
+int InsertBlankTrace(char *comment, TraceFlagsType different_flags)
 {
 TempBuffer tb;
 char *comm;
