@@ -19,7 +19,7 @@ inside_iteration++;
 
 while (gtk_events_pending()) gtk_main_iteration();
 
-inside_iteration--; 
+inside_iteration--;
 }
 
 gboolean in_main_iteration(void)
@@ -36,6 +36,8 @@ return(GLOBALS->splash_is_loading != 0);
 
 static void GuiDoEvent(GdkEvent *event, gpointer data)
 {
+(void)data;
+
 if(!GLOBALS->busy_busy_c_1)
 	{
 	gtk_main_do_event(event);
@@ -58,7 +60,7 @@ if(!GLOBALS->busy_busy_c_1)
 
 	/* now it has been updated to remove keyboard/mouse input */
 
-	switch (event->type) 
+	switch (event->type)
 		{
 		/* more may be needed to be added in the future */
 		case GDK_MOTION_NOTIFY:
@@ -73,7 +75,7 @@ if(!GLOBALS->busy_busy_c_1)
 #endif
 			/* printf("event->type: %d\n", event->type); */
 			break;
-	
+
 		default:
 	            	gtk_main_do_event(event);
 			/* printf("event->type: %d\n", event->type); */
@@ -96,21 +98,21 @@ if(GLOBALS->partial_vcd)
 
 	set_window_busy(NULL);
 
-	while (gtk_events_pending()) 
+	while (gtk_events_pending())
 		{
 		gtk_main_iteration();
 		if(GLOBALS != g_old)
-			{	
+			{
 			/* this should never happen! */
 			/* if it does, the program state is probably screwed */
 			fprintf(stderr, "GTKWAVE | WARNING: globals changed during gtkwave_main_iteration()!\n");
 			gcache = GLOBALS;
 			}
 		}
-	
+
 	set_GLOBALS(g_old);
 	set_window_idle(NULL);
-	
+
 	if(gcache)
 		{
 		set_GLOBALS(gcache);
@@ -128,7 +130,7 @@ gdk_event_handler_set((GdkEventFunc)GuiDoEvent, NULL, NULL);
 
 void set_window_busy_no_refresh(GtkWidget *w)
 {
-int i;
+unsigned int i;
 
 /* if(GLOBALS->tree_dnd_begin) return; */
 
@@ -155,7 +157,7 @@ busy_window_refresh();
 
 void set_window_idle(GtkWidget *w)
 {
-int i;
+unsigned int i;
 
 /* if(GLOBALS->tree_dnd_begin) return; */
 
