@@ -136,6 +136,8 @@ WV_MENU_EDFSD,
 WV_MENU_EDFB,
 WV_MENU_EDFO,
 WV_MENU_EDFA,
+WV_MENU_TIME,
+WV_MENU_ENUM,
 WV_MENU_EDRL,
 WV_MENU_EDR2BON,
 WV_MENU_EDR2BOFF,
