@@ -55,6 +55,12 @@ static void toggle4_callback(GtkWidget *widget, GtkWidget *nothing)
 
 toggle_generic(widget, TR_EXCLUDE);
 }
+static void toggle5_callback(GtkWidget *widget, GtkWidget *nothing)
+{
+(void)nothing;
+
+toggle_generic(widget, TR_POPCNT);
+}
 
 static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 {
@@ -92,8 +98,24 @@ static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 	{
 	GLOBALS->flags_showchange_c_1|=TR_ASCII;
 	}
+  else
+  if(GTK_TOGGLE_BUTTON(GLOBALS->button7_showchange_c_1)->active)
+	{
+	GLOBALS->flags_showchange_c_1|=TR_REAL;
+	}
+  else
+  if(GTK_TOGGLE_BUTTON(GLOBALS->button8_showchange_c_1)->active)
+	{
+	GLOBALS->flags_showchange_c_1|=(TR_TIME|TR_DEC);
+	}
+  else
+  if(GTK_TOGGLE_BUTTON(GLOBALS->button9_showchange_c_1)->active)
+	{
+	GLOBALS->flags_showchange_c_1|=(TR_ENUM|TR_BIN);
+	}
 
   GLOBALS->tcache_showchange_c_1->flags=GLOBALS->flags_showchange_c_1;
+  GLOBALS->tcache_showchange_c_1->minmax_valid = 0; /* force analog traces to regenerate if necessary */
 
   wave_gtk_grab_remove(GLOBALS->window_showchange_c_8);
   gtk_widget_destroy(GLOBALS->window_showchange_c_8);
@@ -173,7 +195,7 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
 
   GLOBALS->button2_showchange_c_1 = gtk_radio_button_new_with_label(group, "Decimal");
   gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button2_showchange_c_1, TRUE, TRUE, 0);
-  if(GLOBALS->flags_showchange_c_1&TR_DEC) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button2_showchange_c_1), TRUE);
+  if((GLOBALS->flags_showchange_c_1&TR_DEC) && (!(GLOBALS->flags_showchange_c_1&TR_TIME))) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button2_showchange_c_1), TRUE);
   gtk_widget_show (GLOBALS->button2_showchange_c_1);
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (GLOBALS->button2_showchange_c_1));
 
@@ -185,7 +207,7 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
 
   GLOBALS->button3_showchange_c_1 = gtk_radio_button_new_with_label(group, "Binary");
   gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button3_showchange_c_1, TRUE, TRUE, 0);
-  if(GLOBALS->flags_showchange_c_1&TR_BIN) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button3_showchange_c_1), TRUE);
+  if((GLOBALS->flags_showchange_c_1&TR_BIN) && (!(GLOBALS->flags_showchange_c_1&TR_ENUM))) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button3_showchange_c_1), TRUE);
   gtk_widget_show (GLOBALS->button3_showchange_c_1);
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (GLOBALS->button3_showchange_c_1));
 
@@ -199,6 +221,24 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
   gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button6_showchange_c_1, TRUE, TRUE, 0);
   if(GLOBALS->flags_showchange_c_1&TR_ASCII) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button6_showchange_c_1), TRUE);
   gtk_widget_show (GLOBALS->button6_showchange_c_1);
+  group = gtk_radio_button_group (GTK_RADIO_BUTTON (GLOBALS->button6_showchange_c_1));
+
+  GLOBALS->button7_showchange_c_1 = gtk_radio_button_new_with_label(group, "Real");
+  gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button7_showchange_c_1, TRUE, TRUE, 0);
+  if(GLOBALS->flags_showchange_c_1&TR_ASCII) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button7_showchange_c_1), TRUE);
+  gtk_widget_show (GLOBALS->button7_showchange_c_1);
+  group = gtk_radio_button_group (GTK_RADIO_BUTTON (GLOBALS->button7_showchange_c_1));
+
+  GLOBALS->button8_showchange_c_1 = gtk_radio_button_new_with_label(group, "Time");
+  gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button8_showchange_c_1, TRUE, TRUE, 0);
+  if(GLOBALS->flags_showchange_c_1&TR_ASCII) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button8_showchange_c_1), TRUE);
+  gtk_widget_show (GLOBALS->button8_showchange_c_1);
+  group = gtk_radio_button_group (GTK_RADIO_BUTTON (GLOBALS->button8_showchange_c_1));
+
+  GLOBALS->button9_showchange_c_1 = gtk_radio_button_new_with_label(group, "Enum");
+  gtk_box_pack_start (GTK_BOX (box2), GLOBALS->button9_showchange_c_1, TRUE, TRUE, 0);
+  if(GLOBALS->flags_showchange_c_1&TR_ASCII) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (GLOBALS->button9_showchange_c_1), TRUE);
+  gtk_widget_show (GLOBALS->button9_showchange_c_1);
 
   frame2 = gtk_frame_new ("Base");
   gtk_container_border_width (GTK_CONTAINER (frame2), 3);
@@ -243,6 +283,12 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
   gtk_widget_show (GLOBALS->toggle4_showchange_c_1);
   gtkwave_signal_connect (GTK_OBJECT (GLOBALS->toggle4_showchange_c_1), "toggled", GTK_SIGNAL_FUNC(toggle4_callback), NULL);
 
+  GLOBALS->toggle5_showchange_c_1=gtk_check_button_new_with_label("Popcnt");
+  gtk_box_pack_start (GTK_BOX (box1), GLOBALS->toggle5_showchange_c_1, TRUE, TRUE, 0);
+  if(GLOBALS->flags_showchange_c_1&TR_POPCNT)gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(GLOBALS->toggle5_showchange_c_1), TRUE);
+  gtk_widget_show (GLOBALS->toggle5_showchange_c_1);
+  gtkwave_signal_connect (GTK_OBJECT (GLOBALS->toggle5_showchange_c_1), "toggled", GTK_SIGNAL_FUNC(toggle5_callback), NULL);
+
   gtk_container_add (GTK_CONTAINER (main_vbox), hbox);
 
   separator = gtk_hseparator_new ();
