@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -211,64 +211,6 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
 /***************************************************************************/
 
-struct tree *fetchhigh(struct tree *t)
-{
-while(t->child) t=t->child;
-return(t);
-}
-
-struct tree *fetchlow(struct tree *t)
-{
-if(t->child)
-	{
-	t=t->child;
-
-	for(;;)
-		{
-		while(t->next) t=t->next;
-		if(t->child) t=t->child; else break;
-		}
-	}
-return(t);
-}
-
-static void fetchvex2(struct tree *t, char direction, char level)
-{
-while(t)
-	{
-	if(t->child)
-		{
-		if(t->child->child)
-			{
-			fetchvex2(t->child, direction, 1);
-			}
-			else
-			{
-			add_vector_range(NULL, fetchlow(t)->t_which,
-				fetchhigh(t)->t_which, direction);
-			}
-		}
-	if(level) { t=t->next; } else { break; }
-	}
-}
-
-void fetchvex(struct tree *t, char direction)
-{
-if(t)
-	{
-	if(t->child)
-		{
-		fetchvex2(t, direction, 0);
-		}
-		else
-		{
-		add_vector_range(NULL, fetchlow(t)->t_which,
-			fetchhigh(t)->t_which, direction);
-		}
-	}
-}
-
-
 /* call cleanup() on ok/insert functions */
 
 static void
@@ -354,6 +296,7 @@ GLOBALS->bundle_direction_treesearch_gtk1_c=1;
 bundle_callback_generic();
 }
 
+
 static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 {
 (void)nothing;
@@ -361,7 +304,7 @@ static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 Traces tcache;
 int i;
 
-if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
+if((!GLOBALS->selectedtree_treesearch_gtk1_c) || (!GLOBALS->selectedtree_treesearch_gtk1_c->child)) return;
 
 memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
 GLOBALS->traces.total=0;
@@ -369,7 +312,10 @@ GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+GLOBALS->fetchlow = GLOBALS->fetchhigh = -1;
+recurse_fetch_high_low(GLOBALS->selectedtree_treesearch_gtk1_c->child);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
         struct symbol *s;
         s=GLOBALS->facs[i];
@@ -384,7 +330,7 @@ if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
                 {
                 struct symbol *s, *t;
                 s=GLOBALS->facs[i];
@@ -421,7 +367,7 @@ if(GLOBALS->is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
 	int len;
         struct symbol *s, *t;
@@ -475,7 +421,7 @@ Traces tcache;
 int i;
 Trptr tfirst=NULL, tlast=NULL;
 
-if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
+if((!GLOBALS->selectedtree_treesearch_gtk1_c) || (!GLOBALS->selectedtree_treesearch_gtk1_c->child)) return;
 
 memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
 GLOBALS->traces.total=0;
@@ -483,7 +429,10 @@ GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+GLOBALS->fetchlow = GLOBALS->fetchhigh = -1;
+recurse_fetch_high_low(GLOBALS->selectedtree_treesearch_gtk1_c->child);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
         struct symbol *s;
         s=GLOBALS->facs[i];
@@ -498,7 +447,7 @@ if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
                 {
                 struct symbol *s, *t;
                 s=GLOBALS->facs[i];
@@ -535,7 +484,7 @@ if(GLOBALS->is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
 	int len;
         struct symbol *s, *t;
@@ -631,11 +580,14 @@ static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 (void)nothing;
 int i;
 
-if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
+if((!GLOBALS->selectedtree_treesearch_gtk1_c) || (!GLOBALS->selectedtree_treesearch_gtk1_c->child)) return;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+GLOBALS->fetchlow = GLOBALS->fetchhigh = -1;
+recurse_fetch_high_low(GLOBALS->selectedtree_treesearch_gtk1_c->child);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
         struct symbol *s;
         s=GLOBALS->facs[i];
@@ -650,7 +602,7 @@ if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
                 {
                 struct symbol *s, *t;
                 s=GLOBALS->facs[i];
@@ -687,7 +639,7 @@ if(GLOBALS->is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
         {
 	int len;
         struct symbol *s, *t;
